==> CovidSonglinePawit-0.1.tar.gz: CovidSonglinePawit-0.1/setup.py <==
from distutils.core import setup

try:
  with open("README.md","r") as fh:
    long_description = fh.read()
except:
  long_description = 'Sending Covid-19 Report THAILAND by Pawit Kraisornnukhor'

setup(
  name = 'CovidSonglinePawit',         # How you named your package folder (MyLib)
  packages = ['CovidSonglinePawit'],   # Chose the same as "name"
  version = '0.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Sending Covid-19 Report THAILAND by Pawit Kraisornnukhor',   # Give a short description about your library
  long_description=long_description,
  long_description_content_type = "text/markdown",
  author = 'Pawit Kraisornnukhor',                   # Type in your name
  author_email = 'pawit.kr@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/PawitKrai/pawit',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/PawitKrai/CovidSonglinePawit/archive/v_01.tar.gz',    # I explain this later on
  keywords = ['COVID', 'LINE', 'Pawit'],   # Keywords that define your package best
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
  ],
)

==> CovidSonglinePawit-0.2.tar.gz: CovidSonglinePawit-0.2/setup.py <==
from distutils.core import setup

try:
  with open("README.md","r") as fh:
    long_description = fh.read()
except:
  long_description = 'Sending Covid-19 Report THAILAND by Pawit Kraisornnukhor'

setup(
  name = 'CovidSonglinePawit',         # How you named your package folder (MyLib)
  packages = ['CovidSonglinePawit'],   # Chose the same as "name"
  version = '0.2',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Sending Covid-19 Report THAILAND by Pawit Kraisornnukhor',   # Give a short description about your library
  long_description=long_description,
  long_description_content_type = "text/markdown",
  author = 'Pawit Kraisornnukhor',                   # Type in your name
  author_email = 'pawit.kr@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/PawitKrai/CovidSonglinePawit',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/PawitKrai/CovidSonglinePawit/archive/v_02.tar.gz',    # I explain this later on
  keywords = ['COVID', 'LINE', 'Pawit'],   # Keywords that define your package best
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
  ],
)
